import 'package:flutter/material.dart';
import 'package:githo/extracted_widgets/backgroundWidget.dart';
import 'package:githo/helpers/databaseHelper.dart';
import 'package:githo/models/settingsModel.dart';
import 'package:githo/screens/homeScreen.dart';
import 'package:githo/screens/introduction.dart';

class FirstScreen extends StatelessWidget {
  // Return the apropriate first screen:
  // If the app is started for the first time: OnBoardingScreen();
  // Else: the normal HomeScreen();

  Future<Widget> getFirstScreen() async {
    final Settings settings = await DatabaseHelper.instance.getSettings();

    if (settings.showIntroduction) {
      return OnBoardingScreen();
    } else {
      return HomeScreen();
    }
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
      future: getFirstScreen(),
      builder: (context, AsyncSnapshot<Widget> snapshot) {
        if (snapshot.connectionState == ConnectionState.done) {
          if (snapshot.hasData) {
            final Widget firstScreen = snapshot.data!;
            return firstScreen;
          }
        }
        // While loading, do this:
        return const BackgroundWidget(
          child: Center(
            child: CircularProgressIndicator(),
          ),
        );
      },
    );
  }
}
